<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name></name>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">Ecran complet</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished">Exportă</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished">Favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">Rotește în sensul acelor de ceasornic</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">Rotește în sens opus acelor de ceasornic </translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished">Setează ca imagine de fundal</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="unfinished">Restabilire</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished">Informații poză</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Anonim</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Creează</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Album nou</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Șterge</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Doriți să ștergeți acest album?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Gunoi</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favorite</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importă</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Gunoi</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favorite</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Sau trage pozele aici</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Importă tot</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Importă la:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importă</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Disc Sistem</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerie</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Discul este ocupat, momentan nu se poate evacua </translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album nou</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulează</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignoră</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anulează</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Înlocuiește</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportă</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Poze</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documente</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descărcări</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzică</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nume:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Salvează în:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Calitate:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvează</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Selectați alte directoare</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Numele fișierului nu poate fi gol</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>deja exista. Vrei sa o inlocuiesti?</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 Disc</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Disc %1 Gol</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 Criptat</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Volum</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Salvează</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Exportă Poze</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulează</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Ștergere...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Restaurare...</translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anulează</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Șterge</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this photo from the album?</source>
        <translation>Doriți să ștergeți această poză din album?</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n photos from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Are you sure you want to delete this video from the album?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n videos from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n items from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Informații de bază</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalii</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Importă</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Prezentare </translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Redenumire</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportă</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Șterge </translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispozitiv </translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerie</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albume</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album nou</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Poze</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Ecran complet</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajutor</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Afișare în manager de fișiere</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Prezentare</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiază</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Setează ca imagine de fundal</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotește în sensul acelor de ceasornic</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotește în sens opus acelor de ceasornic </translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Precedent</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Următor</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Anulează favorit</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Redenumește album </translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Albumul “%1” eliminat</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Adăugat cu succes la “%1” </translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Importare cu succes</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Importare eșuată</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Exportare eșuată</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Exportare cu succes</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Toate pozele</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Cronologie</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albume</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Ieșire ecran complet/prezentare</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afișare etichete</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vizionare</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Selectează tot</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Mărește</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Micșorează</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album nou</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Pagina sus</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Pagina jos</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importare...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Bliț</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tip</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Mărimea fișierului</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensiunile</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data capturării</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data modificării</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modul de expunere</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programul de expunere</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Timpul de expunere</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Vizor</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Distanța focală</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Vizor maximal</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mod de măsurare</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balansul de alb</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensare bliț</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model cameră</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model lentile</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Spațiul de culori</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etichetă</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Disc Sistem</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Selectare</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Deselectare</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Importat la</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation>%1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Importat la</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restabilire</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Șterge </translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Poze</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotește în sens opus acelor de ceasornic </translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotește în sensul acelor de ceasornic</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importare...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Nici-un rezultat</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Prezentare</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Rezultatele căutării</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Vizionare</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Ecran complet</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportă</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Anulează favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotește în sensul acelor de ceasornic</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotește în sens opus acelor de ceasornic </translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Afișează în managerul de fișiere</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Setează ca imagine de fundal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Șterge</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Prezentare</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiere</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Informații poză</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Adăugare la album</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eliminare din album</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restabilire</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album nou</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Printare</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished">zile</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">Informații de bază</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">Data modificării</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Tip</translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished">Mărimea fișierului</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">Data capturării</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
